pub trait AsQuery {
// Required method
fn as_query(&self) -> Result<Option<String>>;
}Expand description
A helper to express the deserialization of a query string to some consistent result type
pub trait AsQuery {
// Required method
fn as_query(&self) -> Result<Option<String>>;
}A helper to express the deserialization of a query string to some consistent result type