pub enum Authorization {
Ucan(Ucan),
Cid(Cid),
}Expand description
An Authorization is a wrapper around something that can be resolved into a Ucan. Typically this is a Cid, but it may also be something like a Ucan itself, or a UcanIpld, or a Jwt. We don’t want to deal with each of these heterogenous types separately, so we move them around as an Authorization instead. TODO(ucan-wg/rs-ucan#32): Maybe swap this out is we get a substantially similar construct to land in rs-ucan
Variants
Implementations
Sourceimpl Authorization
impl Authorization
Sourcepub async fn as_ucan<S: UcanJwtStore>(&self, store: &S) -> Result<Ucan>
pub async fn as_ucan<S: UcanJwtStore>(&self, store: &S) -> Result<Ucan>
Attempt to resolve the Authorization as a fully deserialized Ucan (if it is not one already).
Sourcepub async fn as_proof_chain<S: UcanJwtStore>(
&self,
store: &S,
) -> Result<ProofChain>
pub async fn as_proof_chain<S: UcanJwtStore>( &self, store: &S, ) -> Result<ProofChain>
Attempt to resolve the Authorization as a ProofChain (via its associated Ucan)