pub enum MapOperation<Key, Value> {
Add {
key: Key,
value: Value,
},
Remove {
key: Key,
},
}Expand description
A MapOperation represents a single change to a VersionedMapIpld as it may be recorded in a ChangelogIpld.
Variants
Add
A MapOperation that represents an update or insert to a VersionedMapIpld
Fields

key: KeyThe key that was updated or inserted

value: ValueThe new value associated with the key
Remove
A MapOperation that represents a removal of a key from a VersionedMapIpld
Fields

key: KeyThe key that was removed