BodyChunkIpld

Struct BodyChunkIpld 

pub struct BodyChunkIpld {
    pub bytes: Vec<u8>,
    pub next: Option<Cid>,
}
A body chunk is a simplified flexible byte layout used for linking chunks of bytes. This is necessary to support cases when body contents byte size exceeds the IPFS block size (~1MB). This may be replaced with a more sophisticated layout structure in the future.

Fields

bytes: Vec<u8>

A chunk of bytes

next: Option<Cid>

An optional pointer to the next chunk of bytes, if there are any remaining

Implementations

Source

impl BodyChunkIpld

pub async fn store_bytes<S: BlockStore>( bytes: &[u8], store: &mut S, ) -> Result<Cid>

Chunk and encode a slice of bytes as linked BodyChunkIpld, storing the chunks in storage and returning the Cid of the head of the list.

pub async fn load_all_bytes<S: BlockStore>(&self, store: &S) -> Result<Vec<u8>>

Fold all bytes in the BodyChunkIpld chain into a single buffer and return it