Link

Struct Link 

#[repr(transparent)]
pub struct Link<T>
where T: Clone,
{ pub cid: Cid, /* private fields */ }
A Link is a Cid with a type attached. The type represents the data that the Cid refers to. This is a helpful construct to use to ensure that data structures whose fields or elements may be Cids can still retain strong typing. A Link transparently represents its inner Cid, so a data structure that uses Links can safely be interpretted in terms of Cids, and vice-versa.

Fields

cid: Cid

The wrapped Cid of this Link

Implementations

Source

impl<T> Link<T>
where T: Clone,

pub fn new(cid: Cid) -> Self

Wrap a given Cid in a typed Link

Source

impl<T> Link<T>

pub async fn load_from<S: BlockStore>(&self, store: &S) -> Result<T>

Given a BlockStore, attempt to load a value for the Cid of this Link. The loaded block will be interpretted as the type that is attached to the Cid by this Link, and then returned.

Methods from Deref<Target = Cid>

pub fn version(&self) -> Version

Returns the cid version.

pub fn codec(&self) -> u64

Returns the cid codec.

pub fn hash(&self) -> &Multihash<S>

Returns the cid multihash.

pub fn write_bytes<W>(&self, w: W) -> Result<usize, Error>
where W: Write,

Writes the bytes to a byte stream, returns the number of bytes written.

pub fn encoded_len(&self) -> usize

Returns the length in bytes needed to encode this cid into bytes.

pub fn to_bytes(&self) -> Vec<u8>

Returns the encoded bytes of the Cid.

pub fn to_string_of_base(&self, base: Base) -> Result<String, Error>

Convert CID into a multibase encoded string

Example
use cid::Cid;
use multibase::Base;
use multihash::{Code, MultihashDigest};

const RAW: u64 = 0x55;

let cid = Cid::new_v1(RAW, Code::Sha2_256.digest(b"foo"));
let encoded = cid.to_string_of_base(Base::Base64).unwrap();
assert_eq!(encoded, "mAVUSICwmtGto/8aP+ZtFPB0wQTQTQi1wZIO/oPmKXohiZueu");