VersionedMapIpld

Struct VersionedMapIpld 

pub struct VersionedMapIpld<Key, Value>{
    pub hamt: Cid,
    pub changelog: Cid,
    pub signature: PhantomData<(Key, Value)>,
}
A VersionedMapIpld pairs a Hamt and a ChangelogIpld to enable a data structure that contains its difference from a historical ancestor without requiring that a diff be performed.

Fields

hamt: Cid

A pointer to a Hamt root

changelog: Cid

A pointer to a ChangelogIpld

signature: PhantomData<(Key, Value)>

Implementations

Source

impl<Key, Value> VersionedMapIpld<Key, Value>

pub async fn load_hamt<S: BlockStore>( &self, store: &S, ) -> Result<Hamt<S, Value, Key, Sha256>>

Load the Hamt root associated with this VersionedMapIpld

pub async fn load_changelog<S: BlockStore>( &self, store: &S, ) -> Result<ChangelogIpld<MapOperation<Key, Value>>>

Load the ChangelogIpld associated with this VersionedMapIpld

pub async fn empty<S: BlockStore>(store: &mut S) -> Result<Self>

Initialize an empty VersionedMapIpld, creating an empty Hamt root and ChangelogIpld as well