pub struct VersionedMapIpld<Key, Value>where
Key: VersionedMapKey,
Value: VersionedMapValue,{
pub hamt: Cid,
pub changelog: Cid,
pub signature: PhantomData<(Key, Value)>,
}Expand description
A VersionedMapIpld pairs a Hamt and a ChangelogIpld to enable a data structure that contains its difference from a historical ancestor without requiring that a diff be performed.
Fields
hamt: CidA pointer to a Hamt root
changelog: CidA pointer to a ChangelogIpld
signature: PhantomData<(Key, Value)>Implementations
Sourceimpl<Key, Value> VersionedMapIpld<Key, Value>where
Key: VersionedMapKey,
Value: VersionedMapValue,
impl<Key, Value> VersionedMapIpld<Key, Value>where
Key: VersionedMapKey,
Value: VersionedMapValue,
Sourcepub async fn load_hamt<S: BlockStore>(
&self,
store: &S,
) -> Result<Hamt<S, Value, Key, Sha256>>
pub async fn load_hamt<S: BlockStore>( &self, store: &S, ) -> Result<Hamt<S, Value, Key, Sha256>>
Load the Hamt root associated with this VersionedMapIpld
Sourcepub async fn load_changelog<S: BlockStore>(
&self,
store: &S,
) -> Result<ChangelogIpld<MapOperation<Key, Value>>>
pub async fn load_changelog<S: BlockStore>( &self, store: &S, ) -> Result<ChangelogIpld<MapOperation<Key, Value>>>
Load the ChangelogIpld associated with this VersionedMapIpld
Sourcepub async fn empty<S: BlockStore>(store: &mut S) -> Result<Self>
pub async fn empty<S: BlockStore>(store: &mut S) -> Result<Self>
Initialize an empty VersionedMapIpld, creating an empty Hamt root and ChangelogIpld as well